@@ -33,10 +33,13 @@ Config::Config() : schemaPath_(""), schemaPathInitialised_(false) {
     userConfig_ = std::make_shared<eckit::LocalConfiguration>(eckit::LocalConfiguration());
 }
 
-Config Config::make(const eckit::PathName& path, const eckit::Configuration& userConfig) {
+Config Config::make(const eckit::PathName& path, const eckit::Configuration& userConfig, const std::string& fdb_home) {
     LOG_DEBUG_LIB(LibFdb5) << "Using FDB configuration file: " << path << std::endl;
     Config cfg{YAMLConfiguration(path)};
     cfg.set("configSource", path);
+    if (!fdb_home.empty()) {
+        cfg.set("fdb_home", fdb_home);
+    }
     cfg.userConfig_ = std::make_shared<eckit::LocalConfiguration>(userConfig);
 
     return cfg;
@@ -102,7 +105,8 @@ Config Config::expandConfig() const {
     }
 
     if (found) {
-        return Config::make(actual_path, userConfig_ ? *userConfig_ : eckit::LocalConfiguration());
+        return Config::make(actual_path, userConfig_ ? *userConfig_ : eckit::LocalConfiguration(),
+                            getString("fdb_home", ""));
     }
 
     // No expandable config available. Use the skeleton config.
@@ -130,8 +134,9 @@ PathName Config::expandPath(const std::string& path) const {
             std::transform(key.begin(), key.end(), key.begin(), ::tolower);
 
             if (has(key)) {
-                std::string newpath = getString(key) + path.substr(slashpos);
-                return PathName(newpath);
+                PathName newpath = getString(key);
+                newpath += path.substr(slashpos);
+                return newpath;
             }
         }
     }
@@ -173,7 +178,6 @@ void Config::initializeSchemaPath() const {
         //       N.B. this uses Config expandPath()
         static std::string fdbSchemaFile =
             Resource<std::string>("fdbSchemaFile;$FDB_SCHEMA_FILE", "~fdb/etc/fdb/schema");
-
         schemaPath_ = expandPath(fdbSchemaFile);
     }
 
